@@ -909,7 +909,6 @@ class DataframeType(BaseType):
                 valid_term = valid_term or (codelist_term_map[codelist].get("extensible") or set(terms_list).issubset(codelist_term_map[codelist].get("allowed_terms", [])))
         return valid_term
 
-
     @type_operator(FIELD_DATAFRAME)
     def has_different_values(self, other_value: dict):
         """
@@ -923,6 +922,36 @@ class DataframeType(BaseType):
     def has_same_values(self, other_value: dict):
         return ~self.has_different_values(other_value)
 
+    @type_operator(FIELD_DATAFRAME)
+    def is_ordered_by(self, other_value: dict) -> pd.Series:
+        """
+        Checking validity based on target order.
+        """
+        target: str = self.replace_prefix(other_value.get("target"))
+        sort_order: str =other_value.get("order","asc")
+        if sort_order not in ["asc","dsc"]:
+            raise ValueError ("invalid sorting order")
+        sort_order_bool: bool = sort_order == "asc"
+        return self.value[target].eq(self.value[target].sort_values(ascending=sort_order_bool, ignore_index=True))
+
+    @type_operator(FIELD_DATAFRAME)
+    def is_not_ordered_by(self, other_value: dict) -> pd.Series:
+        return ~self.is_ordered_by(other_value)
+
+    @type_operator(FIELD_DATAFRAME)
+    def value_has_multiple_references(self, other_value: dict) -> pd.Series:
+        """
+        Requires a target column and a reference count column whose values
+        are a dictionary containing the number of times that value appears.
+        """
+        target: str = self.replace_prefix(other_value.get("target"))
+        reference_count_column: str = self.replace_prefix(other_value.get("comparator"))
+        result = np.where(vectorized_get_dict_key(self.value[reference_count_column], self.value[target]) > 1, True, False)
+        return pd.Series(result)
+
+    @type_operator(FIELD_DATAFRAME)
+    def value_does_not_have_multiple_references(self, other_value: dict) -> pd.Series:
+        return ~self.value_has_multiple_references(other_value)
 
 @export_type
 class GenericType(SelectMultipleType, SelectType, StringType, NumericType, BooleanType):
